# coding: utf-8

"""
    AssistedInstall

    Assisted installation  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class Memory(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'physical_bytes': 'int',
        'usable_bytes': 'int',
        'physical_bytes_method': 'MemoryMethod'
    }

    attribute_map = {
        'physical_bytes': 'physical_bytes',
        'usable_bytes': 'usable_bytes',
        'physical_bytes_method': 'physical_bytes_method'
    }

    def __init__(self, physical_bytes=None, usable_bytes=None, physical_bytes_method=None):  # noqa: E501
        """Memory - a model defined in Swagger"""  # noqa: E501

        self._physical_bytes = None
        self._usable_bytes = None
        self._physical_bytes_method = None
        self.discriminator = None

        if physical_bytes is not None:
            self.physical_bytes = physical_bytes
        if usable_bytes is not None:
            self.usable_bytes = usable_bytes
        if physical_bytes_method is not None:
            self.physical_bytes_method = physical_bytes_method

    @property
    def physical_bytes(self):
        """Gets the physical_bytes of this Memory.  # noqa: E501


        :return: The physical_bytes of this Memory.  # noqa: E501
        :rtype: int
        """
        return self._physical_bytes

    @physical_bytes.setter
    def physical_bytes(self, physical_bytes):
        """Sets the physical_bytes of this Memory.


        :param physical_bytes: The physical_bytes of this Memory.  # noqa: E501
        :type: int
        """

        self._physical_bytes = physical_bytes

    @property
    def usable_bytes(self):
        """Gets the usable_bytes of this Memory.  # noqa: E501


        :return: The usable_bytes of this Memory.  # noqa: E501
        :rtype: int
        """
        return self._usable_bytes

    @usable_bytes.setter
    def usable_bytes(self, usable_bytes):
        """Sets the usable_bytes of this Memory.


        :param usable_bytes: The usable_bytes of this Memory.  # noqa: E501
        :type: int
        """

        self._usable_bytes = usable_bytes

    @property
    def physical_bytes_method(self):
        """Gets the physical_bytes_method of this Memory.  # noqa: E501

        The method by which the physical memory was set  # noqa: E501

        :return: The physical_bytes_method of this Memory.  # noqa: E501
        :rtype: MemoryMethod
        """
        return self._physical_bytes_method

    @physical_bytes_method.setter
    def physical_bytes_method(self, physical_bytes_method):
        """Sets the physical_bytes_method of this Memory.

        The method by which the physical memory was set  # noqa: E501

        :param physical_bytes_method: The physical_bytes_method of this Memory.  # noqa: E501
        :type: MemoryMethod
        """

        self._physical_bytes_method = physical_bytes_method

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Memory, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Memory):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
